# Apache Configuration

To use this language, use the class "language-apacheconf".

## Comments

    # This is a comment
    # <VirtualHost *:80>

## Directives

    <Files .htaccess>
    	Order allow,deny
    	Deny from all
    </Files>

## Variables

    RewriteCond %{REQUEST_FILENAME}.php -f

## Regex

    ^(.*)$
    !^www\.

## Directive flags

    [NC]
    [RC=301,L]

## Strings

    AuthName "Fichiers réservés"

## Full example

    ## BASIC PASSWORD PROTECTION
    AuthType basic
    AuthName "prompt"
    AuthUserFile /.htpasswd
    AuthGroupFile /dev/null
    Require valid-user

    ## ALLOW FROM IP OR VALID PASSWORD
    Require valid-user
    Allow from 192.168.1.23
    Satisfy Any

    ## PROTECT FILES
    Order Allow,Deny
    Deny from all

    ## REQUIRE SUBDOMAIN
    RewriteCond %{HTTP_HOST} !^$
    RewriteCond %{HTTP_HOST} !^subdomain\.domain\.tld$ [NC]
    RewriteRule ^/(.*)$ http://subdomain.domain.tld/$1 [L,R=301]

    ErrorDocument 403 http://www.example.com/logo.gif
    ErrorDocument 403 /images/you_bad_hotlinker.gif

    ## REDIRECT UPLOADS
    RewriteCond %{REQUEST_METHOD} ^(PUT|POST)$ [NC]
    RewriteRule ^(.*)$ /cgi-bin/form-upload-processor.cgi?p=$1 [L,QSA]